from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class UserCls:
	"""User commands group definition. 40 total commands, 12 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("user", core, parent)

	@property
	def iq(self):
		"""iq commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_iq'):
			from .Iq import IqCls
			self._iq = IqCls(self._core, self._cmd_group)
		return self._iq

	@property
	def spectrum(self):
		"""spectrum commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_spectrum'):
			from .Spectrum import SpectrumCls
			self._spectrum = SpectrumCls(self._core, self._cmd_group)
		return self._spectrum

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	@property
	def fstate(self):
		"""fstate commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_fstate'):
			from .Fstate import FstateCls
			self._fstate = FstateCls(self._core, self._cmd_group)
		return self._fstate

	@property
	def scope(self):
		"""scope commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_scope'):
			from .Scope import ScopeCls
			self._scope = ScopeCls(self._core, self._cmd_group)
		return self._scope

	@property
	def adjust(self):
		"""adjust commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_adjust'):
			from .Adjust import AdjustCls
			self._adjust = AdjustCls(self._core, self._cmd_group)
		return self._adjust

	@property
	def valid(self):
		"""valid commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_valid'):
			from .Valid import ValidCls
			self._valid = ValidCls(self._core, self._cmd_group)
		return self._valid

	@property
	def scovered(self):
		"""scovered commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_scovered'):
			from .Scovered import ScoveredCls
			self._scovered = ScoveredCls(self._core, self._cmd_group)
		return self._scovered

	@property
	def store(self):
		"""store commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_store'):
			from .Store import StoreCls
			self._store = StoreCls(self._core, self._cmd_group)
		return self._store

	@property
	def flist(self):
		"""flist commands group. 8 Sub-classes, 1 commands."""
		if not hasattr(self, '_flist'):
			from .Flist import FlistCls
			self._flist = FlistCls(self._core, self._cmd_group)
		return self._flist

	@property
	def slist(self):
		"""slist commands group. 8 Sub-classes, 2 commands."""
		if not hasattr(self, '_slist'):
			from .Slist import SlistCls
			self._slist = SlistCls(self._core, self._cmd_group)
		return self._slist

	@property
	def pstate(self):
		"""pstate commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pstate'):
			from .Pstate import PstateCls
			self._pstate = PstateCls(self._core, self._cmd_group)
		return self._pstate

	def preset(self) -> None:
		"""SCPI: [SENSe]:CORRection:FRESponse:USER:PRESet \n
		Snippet: driver.sense.correction.fresponse.user.preset() \n
		No command help available \n
		"""
		self._core.io.write(f'SENSe:CORRection:FRESponse:USER:PRESet')

	def preset_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: [SENSe]:CORRection:FRESponse:USER:PRESet \n
		Snippet: driver.sense.correction.fresponse.user.preset_with_opc() \n
		No command help available \n
		Same as preset, but waits for the operation to complete before continuing further. Use the RsFswp.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SENSe:CORRection:FRESponse:USER:PRESet', opc_timeout_ms)

	def load(self, file_path: str) -> None:
		"""SCPI: [SENSe]:CORRection:FRESponse:USER:LOAD \n
		Snippet: driver.sense.correction.fresponse.user.load(file_path = '1') \n
		No command help available \n
			:param file_path: No help available
		"""
		param = Conversions.value_to_quoted_str(file_path)
		self._core.io.write(f'SENSe:CORRection:FRESponse:USER:LOAD {param}')

	def clone(self) -> 'UserCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = UserCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.RepeatedCapability import RepeatedCapability
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RangeCls:
	"""Range commands group definition. 26 total commands, 11 Subgroups, 1 group commands
	Repeated Capability: RangePy, default value after init: RangePy.Ix1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("range", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_rangePy_get', 'repcap_rangePy_set', repcap.RangePy.Ix1)

	def repcap_rangePy_set(self, rangePy: repcap.RangePy) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to RangePy.Default
		Default value after init: RangePy.Ix1"""
		self._cmd_group.set_repcap_enum_value(rangePy)

	def repcap_rangePy_get(self) -> repcap.RangePy:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def bandwidth(self):
		"""bandwidth commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_bandwidth'):
			from .Bandwidth import BandwidthCls
			self._bandwidth = BandwidthCls(self._core, self._cmd_group)
		return self._bandwidth

	@property
	def insert(self):
		"""insert commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_insert'):
			from .Insert import InsertCls
			self._insert = InsertCls(self._core, self._cmd_group)
		return self._insert

	@property
	def count(self):
		"""count commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_count'):
			from .Count import CountCls
			self._count = CountCls(self._core, self._cmd_group)
		return self._count

	@property
	def filterPy(self):
		"""filterPy commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_filterPy'):
			from .FilterPy import FilterPyCls
			self._filterPy = FilterPyCls(self._core, self._cmd_group)
		return self._filterPy

	@property
	def frequency(self):
		"""frequency commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_frequency'):
			from .Frequency import FrequencyCls
			self._frequency = FrequencyCls(self._core, self._cmd_group)
		return self._frequency

	@property
	def inputPy(self):
		"""inputPy commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_inputPy'):
			from .InputPy import InputPyCls
			self._inputPy = InputPyCls(self._core, self._cmd_group)
		return self._inputPy

	@property
	def refLevel(self):
		"""refLevel commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_refLevel'):
			from .RefLevel import RefLevelCls
			self._refLevel = RefLevelCls(self._core, self._cmd_group)
		return self._refLevel

	@property
	def sweep(self):
		"""sweep commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_sweep'):
			from .Sweep import SweepCls
			self._sweep = SweepCls(self._core, self._cmd_group)
		return self._sweep

	@property
	def limit(self):
		"""limit commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_limit'):
			from .Limit import LimitCls
			self._limit = LimitCls(self._core, self._cmd_group)
		return self._limit

	@property
	def transducer(self):
		"""transducer commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_transducer'):
			from .Transducer import TransducerCls
			self._transducer = TransducerCls(self._core, self._cmd_group)
		return self._transducer

	@property
	def mlCalc(self):
		"""mlCalc commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mlCalc'):
			from .MlCalc import MlCalcCls
			self._mlCalc = MlCalcCls(self._core, self._cmd_group)
		return self._mlCalc

	def delete(self, subBlock=repcap.SubBlock.Default, rangePy=repcap.RangePy.Default) -> None:
		"""SCPI: [SENSe]:ESPectrum<sb>:RANGe<ri>:DELete \n
		Snippet: driver.sense.espectrum.range.delete(subBlock = repcap.SubBlock.Default, rangePy = repcap.RangePy.Default) \n
		No command help available \n
			:param subBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Espectrum')
			:param rangePy: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Range')
		"""
		subBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(subBlock, repcap.SubBlock)
		rangePy_cmd_val = self._cmd_group.get_repcap_cmd_value(rangePy, repcap.RangePy)
		self._core.io.write(f'SENSe:ESPectrum{subBlock_cmd_val}:RANGe{rangePy_cmd_val}:DELete')

	def delete_with_opc(self, subBlock=repcap.SubBlock.Default, rangePy=repcap.RangePy.Default, opc_timeout_ms: int = -1) -> None:
		subBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(subBlock, repcap.SubBlock)
		rangePy_cmd_val = self._cmd_group.get_repcap_cmd_value(rangePy, repcap.RangePy)
		"""SCPI: [SENSe]:ESPectrum<sb>:RANGe<ri>:DELete \n
		Snippet: driver.sense.espectrum.range.delete_with_opc(subBlock = repcap.SubBlock.Default, rangePy = repcap.RangePy.Default) \n
		No command help available \n
		Same as delete, but waits for the operation to complete before continuing further. Use the RsFswp.utilities.opc_timeout_set() to set the timeout value. \n
			:param subBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Espectrum')
			:param rangePy: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Range')
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SENSe:ESPectrum{subBlock_cmd_val}:RANGe{rangePy_cmd_val}:DELete', opc_timeout_ms)

	def clone(self) -> 'RangeCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = RangeCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class OrientationCls:
	"""Orientation commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("orientation", core, parent)

	def set(self, orientation: enums.PageOrientation) -> None:
		"""SCPI: HCOPy:PAGE:ORIentation \n
		Snippet: driver.hardCopy.page.orientation.set(orientation = enums.PageOrientation.LANDscape) \n
		The command selects the page orientation of the printout. The command is only available if the output device is a printer
		or a PDF file. \n
			:param orientation: LANDscape | PORTrait
		"""
		param = Conversions.enum_scalar_to_str(orientation, enums.PageOrientation)
		self._core.io.write(f'HCOPy:PAGE:ORIentation {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.PageOrientation:
		"""SCPI: HCOPy:PAGE:ORIentation \n
		Snippet: value: enums.PageOrientation = driver.hardCopy.page.orientation.get() \n
		The command selects the page orientation of the printout. The command is only available if the output device is a printer
		or a PDF file. \n
			:return: orientation: LANDscape | PORTrait"""
		response = self._core.io.query_str(f'HCOPy:PAGE:ORIentation?')
		return Conversions.str_to_scalar_enum(response, enums.PageOrientation)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from .........Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class EditCls:
	"""Edit commands group definition. 8 total commands, 4 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("edit", core, parent)

	@property
	def next(self):
		"""next commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_next'):
			from .Next import NextCls
			self._next = NextCls(self._core, self._cmd_group)
		return self._next

	@property
	def previous(self):
		"""previous commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_previous'):
			from .Previous import PreviousCls
			self._previous = PreviousCls(self._core, self._cmd_group)
		return self._previous

	@property
	def structure(self):
		"""structure commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_structure'):
			from .Structure import StructureCls
			self._structure = StructureCls(self._core, self._cmd_group)
		return self._structure

	@property
	def text(self):
		"""text commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_text'):
			from .Text import TextCls
			self._text = TextCls(self._core, self._cmd_group)
		return self._text

	def set(self, filename: str) -> None:
		"""SCPI: [SENSe]:DDEMod:PATTern:FRAMe:EDIT \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.pattern.frame.edit.set(filename = '1') \n
		Specifies an xml file for a user-defined frame structure configuration. The default storage location for such files is
		C:/R_S/INSTR/USER/vsa/FrameRangeStructure. This command is only available if the additional Multi-Modulation Analysis
		option (R&S FSWP-K70M) is installed. If the specified file already exists, it is loaded for subsequent editing. Note that
		this command is a prerequisite to editing the frame structure of an existing file (using
		[SENSe:]DDEMod:PATTern:FRAMe:EDIT:STRucture or any other command starting with [SENS:]DDEM:PATT:FRAM:EDIT) . It does not
		load the file for use in the current measurement (see [SENSe:]DDEMod:PATTern:FRAMe:LOAD) . Therefore, you can edit a
		frame structure while simultaneously performing a measurement with another frame structure configuration. If the file
		does not yet exist, a new frame structure is created and will be stored to the specified file when the
		[SENSe:]DDEMod:PATTern:FRAMe:EDIT:SAVE command is executed. \n
			:param filename: string Path and file name of the xml file containing the frame structure configuration.
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SENSe:DDEMod:PATTern:FRAMe:EDIT {param}')

	def get(self) -> str:
		"""SCPI: [SENSe]:DDEMod:PATTern:FRAMe:EDIT \n
		Snippet: value: str = driver.applications.k70Vsa.sense.ddemod.pattern.frame.edit.get() \n
		Specifies an xml file for a user-defined frame structure configuration. The default storage location for such files is
		C:/R_S/INSTR/USER/vsa/FrameRangeStructure. This command is only available if the additional Multi-Modulation Analysis
		option (R&S FSWP-K70M) is installed. If the specified file already exists, it is loaded for subsequent editing. Note that
		this command is a prerequisite to editing the frame structure of an existing file (using
		[SENSe:]DDEMod:PATTern:FRAMe:EDIT:STRucture or any other command starting with [SENS:]DDEM:PATT:FRAM:EDIT) . It does not
		load the file for use in the current measurement (see [SENSe:]DDEMod:PATTern:FRAMe:LOAD) . Therefore, you can edit a
		frame structure while simultaneously performing a measurement with another frame structure configuration. If the file
		does not yet exist, a new frame structure is created and will be stored to the specified file when the
		[SENSe:]DDEMod:PATTern:FRAMe:EDIT:SAVE command is executed. \n
			:return: filename: string Path and file name of the xml file containing the frame structure configuration."""
		response = self._core.io.query_str(f'SENSe:DDEMod:PATTern:FRAMe:EDIT?')
		return trim_str_response(response)

	def save(self, filename: str = None) -> None:
		"""SCPI: [SENSe]:DDEMod:PATTern:FRAMe:EDIT:SAVE \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.pattern.frame.edit.save(filename = '1') \n
		Stores the current frame structure configuration to the specified file. If no path is provided it is saved to the file
		selected previously by [SENSe:]DDEMod:PATTern:FRAMe:EDIT. This command is only available if the additional
		Multi-Modulation Analysis option (R&S FSWP-K70M) is installed. \n
			:param filename: string Optional parameter: Path and file name of the xml file.
		"""
		param = ''
		if filename:
			param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SENSe:DDEMod:PATTern:FRAMe:EDIT:SAVE {param}'.strip())

	def clone(self) -> 'EditCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = EditCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class EautoCls:
	"""Eauto commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("eauto", core, parent)

	# noinspection PyTypeChecker
	def get(self) -> enums.ReferenceSource:
		"""SCPI: [SENSe]:ROSCillator:SOURce:EAUTo \n
		Snippet: value: enums.ReferenceSource = driver.sense.roscillator.source.eauto.get() \n
		This command queries the current reference type in case you have activated an automatic switch to the internal reference
		if the external reference is missing. \n
			:return: reference: INT | EXT INT internal reference EXT external reference"""
		response = self._core.io.query_str(f'SENSe:ROSCillator:SOURce:EAUTo?')
		return Conversions.str_to_scalar_enum(response, enums.ReferenceSource)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, rf_overrange_state: bool) -> None:
		"""SCPI: [SENSe]:MIXer:RFOVerrange[:STATe] \n
		Snippet: driver.applications.k50Spurious.sense.mixer.rfOverrange.state.set(rf_overrange_state = False) \n
		If enabled, the band limits are extended beyond 'RF Start' and 'RF Stop' due to the capabilities of the used harmonics. \n
			:param rf_overrange_state: No help available
		"""
		param = Conversions.bool_to_str(rf_overrange_state)
		self._core.io.write(f'SENSe:MIXer:RFOVerrange:STATe {param}')

	def get(self) -> bool:
		"""SCPI: [SENSe]:MIXer:RFOVerrange[:STATe] \n
		Snippet: value: bool = driver.applications.k50Spurious.sense.mixer.rfOverrange.state.get() \n
		If enabled, the band limits are extended beyond 'RF Start' and 'RF Stop' due to the capabilities of the used harmonics. \n
			:return: rf_overrange_state: No help available"""
		response = self._core.io.query_str(f'SENSe:MIXer:RFOVerrange:STATe?')
		return Conversions.str_to_bool(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ModeCls:
	"""Mode commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mode", core, parent)

	def set(self, mode: enums.IfGainMode) -> None:
		"""SCPI: SYSTem:IFGain:MODE \n
		Snippet: driver.system.ifGain.mode.set(mode = enums.IfGainMode.NORMal) \n
		No command help available \n
			:param mode: No help available
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.IfGainMode)
		self._core.io.write(f'SYSTem:IFGain:MODE {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.IfGainMode:
		"""SCPI: SYSTem:IFGain:MODE \n
		Snippet: value: enums.IfGainMode = driver.system.ifGain.mode.get() \n
		No command help available \n
			:return: mode: No help available"""
		response = self._core.io.query_str(f'SYSTem:IFGain:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.IfGainMode)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class BlockCls:
	"""Block commands group definition. 3 total commands, 2 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("block", core, parent)

	@property
	def immediate(self):
		"""immediate commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_immediate'):
			from .Immediate import ImmediateCls
			self._immediate = ImmediateCls(self._core, self._cmd_group)
		return self._immediate

	@property
	def conMeas(self):
		"""conMeas commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_conMeas'):
			from .ConMeas import ConMeasCls
			self._conMeas = ConMeasCls(self._core, self._cmd_group)
		return self._conMeas

	def abort(self) -> None:
		"""SCPI: INITiate:BLOCk:ABORt \n
		Snippet: driver.initiate.block.abort() \n
		No command help available \n
		"""
		self._core.io.write(f'INITiate:BLOCk:ABORt')

	def abort_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: INITiate:BLOCk:ABORt \n
		Snippet: driver.initiate.block.abort_with_opc() \n
		No command help available \n
		Same as abort, but waits for the operation to complete before continuing further. Use the RsFswp.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'INITiate:BLOCk:ABORt', opc_timeout_ms)

	def clone(self) -> 'BlockCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = BlockCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from typing import List

from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SpursCls:
	"""Spurs commands group definition. 3 total commands, 2 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("spurs", core, parent)

	@property
	def discrete(self):
		"""discrete commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_discrete'):
			from .Discrete import DiscreteCls
			self._discrete = DiscreteCls(self._core, self._cmd_group)
		return self._discrete

	@property
	def random(self):
		"""random commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_random'):
			from .Random import RandomCls
			self._random = RandomCls(self._core, self._cmd_group)
		return self._random

	def get(self, trace=repcap.Trace.Default) -> List[float]:
		"""SCPI: FETCh:PNOise<t>:SPURs \n
		Snippet: value: List[float] = driver.applications.k40PhaseNoise.fetch.pnoise.spurs.get(trace = repcap.Trace.Default) \n
		This command queries the location and level of all spurs that have been detected. \n
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Pnoise')
			:return: spurs: No help available"""
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		response = self._core.io.query_bin_or_ascii_float_list(f'FETCh:PNOise{trace_cmd_val}:SPURs?')
		return response

	def clone(self) -> 'SpursCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SpursCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NonePyCls:
	"""NonePy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("nonePy", core, parent)

	def set(self) -> None:
		"""SCPI: MMEMory:SELect[:ITEM]:NONE \n
		Snippet: driver.massMemory.select.item.nonePy.set() \n
		This command does not include any of the following items when storing or loading a configuration file.
			- Hardware configuration: method RsFswp.MassMemory.Select.Item.HwSettings.set
			- Limit lines: method RsFswp.MassMemory.Select.Item.Lines.All.set
			- Spectrogram data: MMEMory:SELect[:ITEM]:SGRam
			- Trace data: MMEMory:SELect[:ITEM]:TRACe<1...3>[:ACTive] \n
		"""
		self._core.io.write(f'MMEMory:SELect:ITEM:NONE')

	def set_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: MMEMory:SELect[:ITEM]:NONE \n
		Snippet: driver.massMemory.select.item.nonePy.set_with_opc() \n
		This command does not include any of the following items when storing or loading a configuration file.
			- Hardware configuration: method RsFswp.MassMemory.Select.Item.HwSettings.set
			- Limit lines: method RsFswp.MassMemory.Select.Item.Lines.All.set
			- Spectrogram data: MMEMory:SELect[:ITEM]:SGRam
			- Trace data: MMEMory:SELect[:ITEM]:TRACe<1...3>[:ACTive] \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsFswp.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'MMEMory:SELect:ITEM:NONE', opc_timeout_ms)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FormatPyCls:
	"""FormatPy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("formatPy", core, parent)

	def set(self, msk_format: enums.MskFormat) -> None:
		"""SCPI: [SENSe]:DDEMod:MSK:FORMat \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.msk.formatPy.set(msk_format = enums.MskFormat.DIFFerential) \n
		This command defines the specific demodulation order for MSK. \n
			:param msk_format: TYPe1 | TYPe2 | NORMal | DIFFerential TYPE1 | NORMal Demodulation order MSK is used. TYPE2 | DIFFerential Demodulation order DMSK is used.
		"""
		param = Conversions.enum_scalar_to_str(msk_format, enums.MskFormat)
		self._core.io.write(f'SENSe:DDEMod:MSK:FORMat {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.MskFormat:
		"""SCPI: [SENSe]:DDEMod:MSK:FORMat \n
		Snippet: value: enums.MskFormat = driver.applications.k70Vsa.sense.ddemod.msk.formatPy.get() \n
		This command defines the specific demodulation order for MSK. \n
			:return: msk_format: TYPe1 | TYPe2 | NORMal | DIFFerential TYPE1 | NORMal Demodulation order MSK is used. TYPE2 | DIFFerential Demodulation order DMSK is used."""
		response = self._core.io.query_str(f'SENSe:DDEMod:MSK:FORMat?')
		return Conversions.str_to_scalar_enum(response, enums.MskFormat)



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class BoostingCls:
	"""Boosting commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("boosting", core, parent)

	def set(self, boosting: float) -> None:
		"""SCPI: [SENSe]:DDEMod:PATTern:FRAMe:EDIT:NEXT:BOOSting \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.pattern.frame.edit.next.boosting.set(boosting = 1.0) \n
		Determines which boosting is used to demodulate the frame next to the last configured subframe. This command is only
		available if the additional Multi-Modulation Analysis option (R&S FSWP-K70M) is installed. \n
			:param boosting: Range: 0.1 to 60
		"""
		param = Conversions.decimal_value_to_str(boosting)
		self._core.io.write(f'SENSe:DDEMod:PATTern:FRAMe:EDIT:NEXT:BOOSting {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:DDEMod:PATTern:FRAMe:EDIT:NEXT:BOOSting \n
		Snippet: value: float = driver.applications.k70Vsa.sense.ddemod.pattern.frame.edit.next.boosting.get() \n
		Determines which boosting is used to demodulate the frame next to the last configured subframe. This command is only
		available if the additional Multi-Modulation Analysis option (R&S FSWP-K70M) is installed. \n
			:return: boosting: Range: 0.1 to 60"""
		response = self._core.io.query_str(f'SENSe:DDEMod:PATTern:FRAMe:EDIT:NEXT:BOOSting?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FrequencyCls:
	"""Frequency commands group definition. 9 total commands, 8 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("frequency", core, parent)

	@property
	def single(self):
		"""single commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_single'):
			from .Single import SingleCls
			self._single = SingleCls(self._core, self._cmd_group)
		return self._single

	@property
	def table(self):
		"""table commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_table'):
			from .Table import TableCls
			self._table = TableCls(self._core, self._cmd_group)
		return self._table

	@property
	def start(self):
		"""start commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_start'):
			from .Start import StartCls
			self._start = StartCls(self._core, self._cmd_group)
		return self._start

	@property
	def stop(self):
		"""stop commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_stop'):
			from .Stop import StopCls
			self._stop = StopCls(self._core, self._cmd_group)
		return self._stop

	@property
	def step(self):
		"""step commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_step'):
			from .Step import StepCls
			self._step = StepCls(self._core, self._cmd_group)
		return self._step

	@property
	def center(self):
		"""center commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_center'):
			from .Center import CenterCls
			self._center = CenterCls(self._core, self._cmd_group)
		return self._center

	@property
	def span(self):
		"""span commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_span'):
			from .Span import SpanCls
			self._span = SpanCls(self._core, self._cmd_group)
		return self._span

	@property
	def points(self):
		"""points commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_points'):
			from .Points import PointsCls
			self._points = PointsCls(self._core, self._cmd_group)
		return self._points

	def clone(self) -> 'FrequencyCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = FrequencyCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LoadCls:
	"""Load commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("load", core, parent)

	def set(self, filename: str) -> None:
		"""SCPI: [SENSe]:DDEMod:PATTern:FRAMe:LOAD \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.pattern.frame.load.set(filename = '1') \n
		Loads a user-defined frame structure configuration to be used by the measurement from an xml file. The default storage
		location for such files is C:/R_S/INSTR/USER/vsa/FrameRangeStructure. This command is only available if the additional
		Multi-Modulation Analysis option (R&S FSWP-K70M) is installed. \n
			:param filename: string Path and file name of the xml file. The default storage location for frame structures is C:/R_S/INSTR/USER/vsa/FrameRange_Structure.
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SENSe:DDEMod:PATTern:FRAMe:LOAD {param}')

	def get(self) -> str:
		"""SCPI: [SENSe]:DDEMod:PATTern:FRAMe:LOAD \n
		Snippet: value: str = driver.applications.k70Vsa.sense.ddemod.pattern.frame.load.get() \n
		Loads a user-defined frame structure configuration to be used by the measurement from an xml file. The default storage
		location for such files is C:/R_S/INSTR/USER/vsa/FrameRangeStructure. This command is only available if the additional
		Multi-Modulation Analysis option (R&S FSWP-K70M) is installed. \n
			:return: filename: string Path and file name of the xml file. The default storage location for frame structures is C:/R_S/INSTR/USER/vsa/FrameRange_Structure."""
		response = self._core.io.query_str(f'SENSe:DDEMod:PATTern:FRAMe:LOAD?')
		return trim_str_response(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class IfFrequencyCls:
	"""IfFrequency commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ifFrequency", core, parent)

	def set(self, frequency: float, outputConnector=repcap.OutputConnector.Default) -> None:
		"""SCPI: OUTPut<up>:IF:IFFRequency \n
		Snippet: driver.output.ifreq.ifFrequency.set(frequency = 1.0, outputConnector = repcap.OutputConnector.Default) \n
		This command defines the frequency for the IF output of the R&S FSWP. The IF frequency of the signal is converted
		accordingly. This command is available in the time domain and if the IF/VIDEO/DEMOD output is configured for IF. \n
			:param frequency: Unit: HZ
			:param outputConnector: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Output')
		"""
		param = Conversions.decimal_value_to_str(frequency)
		outputConnector_cmd_val = self._cmd_group.get_repcap_cmd_value(outputConnector, repcap.OutputConnector)
		self._core.io.write(f'OUTPut{outputConnector_cmd_val}:IF:IFFRequency {param}')

	def get(self, outputConnector=repcap.OutputConnector.Default) -> float:
		"""SCPI: OUTPut<up>:IF:IFFRequency \n
		Snippet: value: float = driver.output.ifreq.ifFrequency.get(outputConnector = repcap.OutputConnector.Default) \n
		This command defines the frequency for the IF output of the R&S FSWP. The IF frequency of the signal is converted
		accordingly. This command is available in the time domain and if the IF/VIDEO/DEMOD output is configured for IF. \n
			:param outputConnector: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Output')
			:return: frequency: Unit: HZ"""
		outputConnector_cmd_val = self._cmd_group.get_repcap_cmd_value(outputConnector, repcap.OutputConnector)
		response = self._core.io.query_str(f'OUTPut{outputConnector_cmd_val}:IF:IFFRequency?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class HeaderCls:
	"""Header commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("header", core, parent)

	def set(self, state: bool) -> None:
		"""SCPI: FORMat:DEXPort:HEADer \n
		Snippet: driver.applications.k70Vsa.formatPy.dexport.header.set(state = False) \n
		This command defines if a file header (including start frequency, sweep time, detector, etc.) is created or not. A short
		header with the instrument model, the version and the date is always transferred. \n
			:param state: ON | OFF | 0 | 1 OFF | 0 Switches the function off ON | 1 Switches the function on
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'FORMat:DEXPort:HEADer {param}')

	def get(self) -> bool:
		"""SCPI: FORMat:DEXPort:HEADer \n
		Snippet: value: bool = driver.applications.k70Vsa.formatPy.dexport.header.get() \n
		This command defines if a file header (including start frequency, sweep time, detector, etc.) is created or not. A short
		header with the instrument model, the version and the date is always transferred. \n
			:return: state: ON | OFF | 0 | 1 OFF | 0 Switches the function off ON | 1 Switches the function on"""
		response = self._core.io.query_str(f'FORMat:DEXPort:HEADer?')
		return Conversions.str_to_bool(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class OutputCls:
	"""Output commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("output", core, parent)

	def set(self, pulse_output: enums.SignalLevel) -> None:
		"""SCPI: SOURce:GENerator:PULSe:TRIGger:OUTPut \n
		Snippet: driver.source.generator.pulse.trigger.output.set(pulse_output = enums.SignalLevel.HIGH) \n
		This command selects the signal type provided at the trigger output connector. The signal can be used, for example, to
		control an external pulse modulator. \n
			:param pulse_output: HIGH Provides a high active pulse at the trigger output. Note that the signal is provided even if internal pulse modulation has been turned off. You can define the pulse characteristics with •method RsFswp.Source.Generator.Pulse.Width.set •method RsFswp.Source.Generator.Pulse.Period.set LOW Provides a low active pulse at the trigger output. Note that the signal is provided even if internal pulse modulation has been turned off. OFF | 0 Provides no signal at the trigger output.
		"""
		param = Conversions.enum_scalar_to_str(pulse_output, enums.SignalLevel)
		self._core.io.write(f'SOURce:GENerator:PULSe:TRIGger:OUTPut {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.SignalLevel:
		"""SCPI: SOURce:GENerator:PULSe:TRIGger:OUTPut \n
		Snippet: value: enums.SignalLevel = driver.source.generator.pulse.trigger.output.get() \n
		This command selects the signal type provided at the trigger output connector. The signal can be used, for example, to
		control an external pulse modulator. \n
			:return: pulse_output: No help available"""
		response = self._core.io.query_str(f'SOURce:GENerator:PULSe:TRIGger:OUTPut?')
		return Conversions.str_to_scalar_enum(response, enums.SignalLevel)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LowCls:
	"""Low commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("low", core, parent)

	def set(self, filename: str) -> None:
		"""SCPI: [SENSe]:MIXer:LOSS:TABLe[:LOW] \n
		Snippet: driver.applications.k60Transient.sense.mixer.loss.table.low.set(filename = '1') \n
		No command help available \n
			:param filename: No help available
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SENSe:MIXer:LOSS:TABLe:LOW {param}')

	def get(self, filename: str) -> str:
		"""SCPI: [SENSe]:MIXer:LOSS:TABLe[:LOW] \n
		Snippet: value: str = driver.applications.k60Transient.sense.mixer.loss.table.low.get(filename = '1') \n
		No command help available \n
			:param filename: No help available
			:return: filename: No help available"""
		param = Conversions.value_to_quoted_str(filename)
		response = self._core.io.query_str(f'SENSe:MIXer:LOSS:TABLe:LOW? {param}')
		return trim_str_response(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FresponseCls:
	"""Fresponse commands group definition. 89 total commands, 4 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("fresponse", core, parent)

	@property
	def user(self):
		"""user commands group. 12 Sub-classes, 2 commands."""
		if not hasattr(self, '_user'):
			from .User import UserCls
			self._user = UserCls(self._core, self._cmd_group)
		return self._user

	@property
	def baseband(self):
		"""baseband commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_baseband'):
			from .Baseband import BasebandCls
			self._baseband = BasebandCls(self._core, self._cmd_group)
		return self._baseband

	@property
	def inputPy(self):
		"""inputPy commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_inputPy'):
			from .InputPy import InputPyCls
			self._inputPy = InputPyCls(self._core, self._cmd_group)
		return self._inputPy

	@property
	def lsources(self):
		"""lsources commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_lsources'):
			from .Lsources import LsourcesCls
			self._lsources = LsourcesCls(self._core, self._cmd_group)
		return self._lsources

	def clone(self) -> 'FresponseCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = FresponseCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, state: bool) -> None:
		"""SCPI: [SENSe]:DDEMod:MFILter[:STATe] \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.mfilter.state.set(state = False) \n
		Use this command to switch the measurement filter off. To switch a measurement filter on,
		use the [SENSe:]DDEMod:MFILter:NAME command. \n
			:param state: OFF | 0 Switches the measurement filter off. ON | 1 Switches the measurement filter specified by [SENSe:]DDEMod:MFILter:NAME on. However, this command is not necessary, as the [SENSe:]DDEMod:MFILter:NAME command automatically switches the selected filter on.
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SENSe:DDEMod:MFILter:STATe {param}')

	def get(self) -> bool:
		"""SCPI: [SENSe]:DDEMod:MFILter[:STATe] \n
		Snippet: value: bool = driver.applications.k70Vsa.sense.ddemod.mfilter.state.get() \n
		Use this command to switch the measurement filter off. To switch a measurement filter on,
		use the [SENSe:]DDEMod:MFILter:NAME command. \n
			:return: state: OFF | 0 Switches the measurement filter off. ON | 1 Switches the measurement filter specified by [SENSe:]DDEMod:MFILter:NAME on. However, this command is not necessary, as the [SENSe:]DDEMod:MFILter:NAME command automatically switches the selected filter on."""
		response = self._core.io.query_str(f'SENSe:DDEMod:MFILter:STATe?')
		return Conversions.str_to_bool(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ScaleCls:
	"""Scale commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("scale", core, parent)

	def set(self, frequency: enums.FrequencyType, window=repcap.Window.Default, trace=repcap.Trace.Default) -> None:
		"""SCPI: DISPlay[:WINDow<n>]:TRACe<t>:X[:SCALe] \n
		Snippet: driver.applications.k30NoiseFigure.display.window.trace.x.scale.set(frequency = enums.FrequencyType.IF, window = repcap.Window.Default, trace = repcap.Trace.Default) \n
		This command selects the type of frequency displayed on the x-axis. \n
			:param frequency: RF | IF | LO IF Intermediary frequency, e.g. for measurements on frequency converting DUTs. RF Radio frequency.
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Trace')
		"""
		param = Conversions.enum_scalar_to_str(frequency, enums.FrequencyType)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		self._core.io.write(f'DISPlay:WINDow{window_cmd_val}:TRACe{trace_cmd_val}:X:SCALe {param}')

	# noinspection PyTypeChecker
	def get(self, window=repcap.Window.Default, trace=repcap.Trace.Default) -> enums.FrequencyType:
		"""SCPI: DISPlay[:WINDow<n>]:TRACe<t>:X[:SCALe] \n
		Snippet: value: enums.FrequencyType = driver.applications.k30NoiseFigure.display.window.trace.x.scale.get(window = repcap.Window.Default, trace = repcap.Trace.Default) \n
		This command selects the type of frequency displayed on the x-axis. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Trace')
			:return: frequency: RF | IF | LO IF Intermediary frequency, e.g. for measurements on frequency converting DUTs. RF Radio frequency."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		response = self._core.io.query_str(f'DISPlay:WINDow{window_cmd_val}:TRACe{trace_cmd_val}:X:SCALe?')
		return Conversions.str_to_scalar_enum(response, enums.FrequencyType)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CountCls:
	"""Count commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("count", core, parent)

	def set(self, average_count: float) -> None:
		"""SCPI: [SENSe]:AVERage:COUNt \n
		Snippet: driver.sense.average.count.set(average_count = 1.0) \n
		This command defines the number of measurements that the application uses to average traces. In case of continuous sweep
		mode, the application calculates the moving average over the average count. In case of single sweep mode, the application
		stops the measurement and calculates the average after the average count has been reached. \n
			:param average_count: If you set an average count of 0 or 1, the application performs one single measurement in single sweep mode. In continuous sweep mode, if the average count is set to 0, a moving average over 10 measurements is performed. Range: 0 to 200000
		"""
		param = Conversions.decimal_value_to_str(average_count)
		self._core.io.write(f'SENSe:AVERage:COUNt {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:AVERage:COUNt \n
		Snippet: value: float = driver.sense.average.count.get() \n
		This command defines the number of measurements that the application uses to average traces. In case of continuous sweep
		mode, the application calculates the moving average over the average count. In case of single sweep mode, the application
		stops the measurement and calculates the average after the average count has been reached. \n
			:return: average_count: If you set an average count of 0 or 1, the application performs one single measurement in single sweep mode. In continuous sweep mode, if the average count is set to 0, a moving average over 10 measurements is performed. Range: 0 to 200000"""
		response = self._core.io.query_str(f'SENSe:AVERage:COUNt?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ResolutionCls:
	"""Resolution commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("resolution", core, parent)

	def set(self, bandwidth: float) -> None:
		"""SCPI: [SENSe]:ADEMod:SPECtrum:BWIDth[:RESolution] \n
		Snippet: driver.sense.ademod.spectrum.bandwidth.resolution.set(bandwidth = 1.0) \n
		Defines the resolution bandwidth for data acquisition. From the specified RBW and the demodulation span set by
		[SENSe:]ADEMod:SPECtrum:SPAN[:MAXimum] or [SENSe:]BWIDth:DEMod, the required measurement time is calculated.
		If the available measurement time is not sufficient for the given bandwidth, the measurement time is set to its maximum
		and the resolution bandwidth is increased to the resulting bandwidth.
		This command is identical to [SENSe:]BANDwidth[:RESolution]. \n
			:param bandwidth: refer to data sheet Unit: HZ
		"""
		param = Conversions.decimal_value_to_str(bandwidth)
		self._core.io.write(f'SENSe:ADEMod:SPECtrum:BWIDth:RESolution {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:ADEMod:SPECtrum:BWIDth[:RESolution] \n
		Snippet: value: float = driver.sense.ademod.spectrum.bandwidth.resolution.get() \n
		Defines the resolution bandwidth for data acquisition. From the specified RBW and the demodulation span set by
		[SENSe:]ADEMod:SPECtrum:SPAN[:MAXimum] or [SENSe:]BWIDth:DEMod, the required measurement time is calculated.
		If the available measurement time is not sufficient for the given bandwidth, the measurement time is set to its maximum
		and the resolution bandwidth is increased to the resulting bandwidth.
		This command is identical to [SENSe:]BANDwidth[:RESolution]. \n
			:return: bandwidth: refer to data sheet Unit: HZ"""
		response = self._core.io.query_str(f'SENSe:ADEMod:SPECtrum:BWIDth:RESolution?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class OffsetCls:
	"""Offset commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("offset", core, parent)

	def set(self, offset: float) -> None:
		"""SCPI: [SENSe]:MSRA:CAPTure:OFFSet \n
		Snippet: driver.applications.k60Transient.sense.msra.capture.offset.set(offset = 1.0) \n
		This setting is only available for secondary applications in MSRA mode, not for the MSRA primary application. It has a
		similar effect as the trigger offset in other measurements. \n
			:param offset: This parameter defines the time offset between the capture buffer start and the start of the extracted secondary application data. The offset must be a positive value, as the secondary application can only analyze data that is contained in the capture buffer. Range: 0 to Record length, Unit: S
		"""
		param = Conversions.decimal_value_to_str(offset)
		self._core.io.write(f'SENSe:MSRA:CAPTure:OFFSet {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:MSRA:CAPTure:OFFSet \n
		Snippet: value: float = driver.applications.k60Transient.sense.msra.capture.offset.get() \n
		This setting is only available for secondary applications in MSRA mode, not for the MSRA primary application. It has a
		similar effect as the trigger offset in other measurements. \n
			:return: offset: This parameter defines the time offset between the capture buffer start and the start of the extracted secondary application data. The offset must be a positive value, as the secondary application can only analyze data that is contained in the capture buffer. Range: 0 to Record length, Unit: S"""
		response = self._core.io.query_str(f'SENSe:MSRA:CAPTure:OFFSet?')
		return Conversions.str_to_float(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StandardCls:
	"""Standard commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("standard", core, parent)

	def set(self, standard: str) -> None:
		"""SCPI: [SENSe]:ADEMod:PRESet[:STANdard] \n
		Snippet: driver.sense.ademod.preset.standard.set(standard = '1') \n
		This command loads a measurement configuration. Standard definitions are stored in an xml file. The default directory for
		Analog Modulation Analysis standards is C:/R_S/INSTR/USER/predefined/AdemodPredefined. \n
			:param standard: String containing the file name. If you have stored the file in a subdirectory of the directory mentioned above, you have to include the relative path to the file.
		"""
		param = Conversions.value_to_quoted_str(standard)
		self._core.io.write(f'SENSe:ADEMod:PRESet:STANdard {param}')

	def get(self) -> str:
		"""SCPI: [SENSe]:ADEMod:PRESet[:STANdard] \n
		Snippet: value: str = driver.sense.ademod.preset.standard.get() \n
		This command loads a measurement configuration. Standard definitions are stored in an xml file. The default directory for
		Analog Modulation Analysis standards is C:/R_S/INSTR/USER/predefined/AdemodPredefined. \n
			:return: standard: String containing the file name. If you have stored the file in a subdirectory of the directory mentioned above, you have to include the relative path to the file."""
		response = self._core.io.query_str(f'SENSe:ADEMod:PRESet:STANdard?')
		return trim_str_response(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TagsCls:
	"""Tags commands group definition. 4 total commands, 2 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("tags", core, parent)

	@property
	def all(self):
		"""all commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_all'):
			from .All import AllCls
			self._all = AllCls(self._core, self._cmd_group)
		return self._all

	@property
	def value(self):
		"""value commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_value'):
			from .Value import ValueCls
			self._value = ValueCls(self._core, self._cmd_group)
		return self._value

	def delete(self, delete_tag: str) -> None:
		"""SCPI: DIAGnostic:HUMS:TAGS:DELete \n
		Snippet: driver.diagnostic.hums.tags.delete(delete_tag = '1') \n
		Deletes a certain tag you assigned to your instrument, including its key and value. \n
			:param delete_tag: ID number of the tag you want to delete. To identify the ID number, query all device tags from the system first. For more information, see method RsFswp.Diagnostic.Hums.Tags.All.get_.
		"""
		param = Conversions.value_to_quoted_str(delete_tag)
		self._core.io.write(f'DIAGnostic:HUMS:TAGS:DELete {param}')

	def delete_all(self) -> None:
		"""SCPI: DIAGnostic:HUMS:TAGS:DELete:ALL \n
		Snippet: driver.diagnostic.hums.tags.delete_all() \n
		Deletes all key-value tags you have assigned to the instrument. \n
		"""
		self._core.io.write(f'DIAGnostic:HUMS:TAGS:DELete:ALL')

	def delete_all_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: DIAGnostic:HUMS:TAGS:DELete:ALL \n
		Snippet: driver.diagnostic.hums.tags.delete_all_with_opc() \n
		Deletes all key-value tags you have assigned to the instrument. \n
		Same as delete_all, but waits for the operation to complete before continuing further. Use the RsFswp.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'DIAGnostic:HUMS:TAGS:DELete:ALL', opc_timeout_ms)

	def clone(self) -> 'TagsCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = TagsCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AdemodCls:
	"""Ademod commands group definition. 12 total commands, 9 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ademod", core, parent)

	@property
	def am(self):
		"""am commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_am'):
			from .Am import AmCls
			self._am = AmCls(self._core, self._cmd_group)
		return self._am

	@property
	def fm(self):
		"""fm commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_fm'):
			from .Fm import FmCls
			self._fm = FmCls(self._core, self._cmd_group)
		return self._fm

	@property
	def pm(self):
		"""pm commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_pm'):
			from .Pm import PmCls
			self._pm = PmCls(self._core, self._cmd_group)
		return self._pm

	@property
	def afrequency(self):
		"""afrequency commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_afrequency'):
			from .Afrequency import AfrequencyCls
			self._afrequency = AfrequencyCls(self._core, self._cmd_group)
		return self._afrequency

	@property
	def freqError(self):
		"""freqError commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_freqError'):
			from .FreqError import FreqErrorCls
			self._freqError = FreqErrorCls(self._core, self._cmd_group)
		return self._freqError

	@property
	def sinad(self):
		"""sinad commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_sinad'):
			from .Sinad import SinadCls
			self._sinad = SinadCls(self._core, self._cmd_group)
		return self._sinad

	@property
	def distortion(self):
		"""distortion commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_distortion'):
			from .Distortion import DistortionCls
			self._distortion = DistortionCls(self._core, self._cmd_group)
		return self._distortion

	@property
	def thd(self):
		"""thd commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_thd'):
			from .Thd import ThdCls
			self._thd = ThdCls(self._core, self._cmd_group)
		return self._thd

	@property
	def carrier(self):
		"""carrier commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_carrier'):
			from .Carrier import CarrierCls
			self._carrier = CarrierCls(self._core, self._cmd_group)
		return self._carrier

	def clone(self) -> 'AdemodCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = AdemodCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LevelCls:
	"""Level commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("level", core, parent)

	def set(self) -> None:
		"""SCPI: [SENSe]:ADJust:LEVel \n
		Snippet: driver.applications.k50Spurious.sense.adjust.level.set() \n
		Initiates a single (internal) measurement that evaluates and sets the ideal reference level for the current input data
		and measurement settings. Thus, the settings of the RF attenuation and the reference level are optimized for the signal
		level. The R&S FSWP is not overloaded and the dynamic range is not limited by an S/N ratio that is too small. \n
		"""
		self._core.io.write(f'SENSe:ADJust:LEVel')

	def set_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: [SENSe]:ADJust:LEVel \n
		Snippet: driver.applications.k50Spurious.sense.adjust.level.set_with_opc() \n
		Initiates a single (internal) measurement that evaluates and sets the ideal reference level for the current input data
		and measurement settings. Thus, the settings of the RF attenuation and the reference level are optimized for the signal
		level. The R&S FSWP is not overloaded and the dynamic range is not limited by an S/N ratio that is too small. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsFswp.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SENSe:ADJust:LEVel', opc_timeout_ms)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.StructBase import StructBase
from ......Internal.ArgStruct import ArgStruct
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TimeCls:
	"""Time commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("time", core, parent)

	# noinspection PyTypeChecker
	class GetStruct(StructBase):
		"""Response structure. Fields: \n
			- Time_X_1: float: No parameter help available
			- Time_X_2: float: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_float('Time_X_1'),
			ArgStruct.scalar_float('Time_X_2')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Time_X_1: float = None
			self.Time_X_2: float = None

	def get(self, window=repcap.Window.Default, marker=repcap.Marker.Default) -> GetStruct:
		"""SCPI: CALCulate<n>:MARKer<m>:FUNCtion:NDBDown:TIME \n
		Snippet: value: GetStruct = driver.calculate.marker.function.ndbDown.time.get(window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		No command help available \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
			:return: structure: for return value, see the help for GetStruct structure arguments."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		return self._core.io.query_struct(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:FUNCtion:NDBDown:TIME?', self.__class__.GetStruct())



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ValueCls:
	"""Value commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("value", core, parent)

	def set(self, arg_0: float, powerMeter=repcap.PowerMeter.Default) -> None:
		"""SCPI: [SENSe]:PMETer<p>:DCYCle:VALue \n
		Snippet: driver.applications.k50Spurious.sense.pmeter.dcycle.value.set(arg_0 = 1.0, powerMeter = repcap.PowerMeter.Default) \n
		This command defines the duty cycle for the correction of pulse signals. The power sensor uses the duty cycle in
		combination with the mean power to calculate the power of the pulse. \n
			:param arg_0: No help available
			:param powerMeter: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Pmeter')
		"""
		param = Conversions.decimal_value_to_str(arg_0)
		powerMeter_cmd_val = self._cmd_group.get_repcap_cmd_value(powerMeter, repcap.PowerMeter)
		self._core.io.write(f'SENSe:PMETer{powerMeter_cmd_val}:DCYCle:VALue {param}')

	def get(self, powerMeter=repcap.PowerMeter.Default) -> float:
		"""SCPI: [SENSe]:PMETer<p>:DCYCle:VALue \n
		Snippet: value: float = driver.applications.k50Spurious.sense.pmeter.dcycle.value.get(powerMeter = repcap.PowerMeter.Default) \n
		This command defines the duty cycle for the correction of pulse signals. The power sensor uses the duty cycle in
		combination with the mean power to calculate the power of the pulse. \n
			:param powerMeter: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Pmeter')
			:return: arg_0: No help available"""
		powerMeter_cmd_val = self._cmd_group.get_repcap_cmd_value(powerMeter, repcap.PowerMeter)
		response = self._core.io.query_str(f'SENSe:PMETer{powerMeter_cmd_val}:DCYCle:VALue?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FrequencyCls:
	"""Frequency commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("frequency", core, parent)

	@property
	def link(self):
		"""link commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_link'):
			from .Link import LinkCls
			self._link = LinkCls(self._core, self._cmd_group)
		return self._link

	def set(self, arg_0: float, powerMeter=repcap.PowerMeter.Default) -> None:
		"""SCPI: [SENSe]:PMETer<p>:FREQuency \n
		Snippet: driver.applications.k50Spurious.sense.pmeter.frequency.set(arg_0 = 1.0, powerMeter = repcap.PowerMeter.Default) \n
		This command defines the frequency of the power sensor. \n
			:param arg_0: No help available
			:param powerMeter: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Pmeter')
		"""
		param = Conversions.decimal_value_to_str(arg_0)
		powerMeter_cmd_val = self._cmd_group.get_repcap_cmd_value(powerMeter, repcap.PowerMeter)
		self._core.io.write(f'SENSe:PMETer{powerMeter_cmd_val}:FREQuency {param}')

	def get(self, powerMeter=repcap.PowerMeter.Default) -> float:
		"""SCPI: [SENSe]:PMETer<p>:FREQuency \n
		Snippet: value: float = driver.applications.k50Spurious.sense.pmeter.frequency.get(powerMeter = repcap.PowerMeter.Default) \n
		This command defines the frequency of the power sensor. \n
			:param powerMeter: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Pmeter')
			:return: arg_0: No help available"""
		powerMeter_cmd_val = self._cmd_group.get_repcap_cmd_value(powerMeter, repcap.PowerMeter)
		response = self._core.io.query_str(f'SENSe:PMETer{powerMeter_cmd_val}:FREQuency?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'FrequencyCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = FrequencyCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SetCls:
	"""Set commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("set", core, parent)

	def set(self, block_data: bytes) -> None:
		"""SCPI: SYSTem:SET \n
		Snippet: driver.system.set.set(block_data = b'ABCDEFGH') \n
		No command help available \n
			:param block_data: No help available
		"""
		self._core.io.write_bin_block(f'SYSTem:SET ', block_data)

	def get(self) -> bytes:
		"""SCPI: SYSTem:SET \n
		Snippet: value: bytes = driver.system.set.get() \n
		No command help available \n
			:return: block_data: No help available"""
		response = self._core.io.query_bin_block_ERROR(f'SYSTem:SET?')
		return response



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AutoCls:
	"""Auto commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("auto", core, parent)

	def set(self, auto: bool, window=repcap.Window.Default, trace=repcap.Trace.Default) -> None:
		"""SCPI: DISPlay[:WINDow<n>]:TRACe<t>:Y[:SCALe]:AUTO \n
		Snippet: driver.display.window.trace.y.scale.auto.set(auto = False, window = repcap.Window.Default, trace = repcap.Trace.Default) \n
		This command turns automatic scaling of the y-axis in graphical result displays on and off. \n
			:param auto: No help available
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Trace')
		"""
		param = Conversions.bool_to_str(auto)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		self._core.io.write(f'DISPlay:WINDow{window_cmd_val}:TRACe{trace_cmd_val}:Y:SCALe:AUTO {param}')



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ModeCls:
	"""Mode commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mode", core, parent)

	def set(self, mode: enums.PwrLevelMode, source=repcap.Source.Default) -> None:
		"""SCPI: SOURce:VOLTage:POWer<i>:LEVel:MODE \n
		Snippet: driver.applications.k30NoiseFigure.source.voltage.power.level.mode.set(mode = enums.PwrLevelMode.CURRent, source = repcap.Source.Default) \n
		No command help available \n
			:param mode: No help available
			:param source: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Power')
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.PwrLevelMode)
		source_cmd_val = self._cmd_group.get_repcap_cmd_value(source, repcap.Source)
		self._core.io.write(f'SOURce:VOLTage:POWer{source_cmd_val}:LEVel:MODE {param}')

	# noinspection PyTypeChecker
	def get(self, source=repcap.Source.Default) -> enums.PwrLevelMode:
		"""SCPI: SOURce:VOLTage:POWer<i>:LEVel:MODE \n
		Snippet: value: enums.PwrLevelMode = driver.applications.k30NoiseFigure.source.voltage.power.level.mode.get(source = repcap.Source.Default) \n
		No command help available \n
			:param source: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Power')
			:return: mode: No help available"""
		source_cmd_val = self._cmd_group.get_repcap_cmd_value(source, repcap.Source)
		response = self._core.io.query_str(f'SOURce:VOLTage:POWer{source_cmd_val}:LEVel:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.PwrLevelMode)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from .........Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AddressCls:
	"""Address commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("address", core, parent)

	def set(self, address: str) -> None:
		"""SCPI: SYSTem:COMMunicate:TCPip:RDEVice:GENerator:ADDRess \n
		Snippet: driver.applications.k30NoiseFigure.system.communicate.tcpip.rdevice.generator.address.set(address = '1') \n
		Configures the TCP/IP address for the external generator. This command is only valid if External Generator Control (R&S
		FSWP-B10) is installed. \n
			:param address: TCP/IP address between 0.0.0.0 and 0.255.255.255
		"""
		param = Conversions.value_to_quoted_str(address)
		self._core.io.write(f'SYSTem:COMMunicate:TCPip:RDEVice:GENerator:ADDRess {param}')

	def get(self) -> str:
		"""SCPI: SYSTem:COMMunicate:TCPip:RDEVice:GENerator:ADDRess \n
		Snippet: value: str = driver.applications.k30NoiseFigure.system.communicate.tcpip.rdevice.generator.address.get() \n
		Configures the TCP/IP address for the external generator. This command is only valid if External Generator Control (R&S
		FSWP-B10) is installed. \n
			:return: address: TCP/IP address between 0.0.0.0 and 0.255.255.255"""
		response = self._core.io.query_str(f'SYSTem:COMMunicate:TCPip:RDEVice:GENerator:ADDRess?')
		return trim_str_response(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SearchCls:
	"""Search commands group definition. 36 total commands, 6 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("search", core, parent)

	@property
	def burst(self):
		"""burst commands group. 8 Sub-classes, 0 commands."""
		if not hasattr(self, '_burst'):
			from .Burst import BurstCls
			self._burst = BurstCls(self._core, self._cmd_group)
		return self._burst

	@property
	def mburst(self):
		"""mburst commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_mburst'):
			from .Mburst import MburstCls
			self._mburst = MburstCls(self._core, self._cmd_group)
		return self._mburst

	@property
	def sync(self):
		"""sync commands group. 14 Sub-classes, 2 commands."""
		if not hasattr(self, '_sync'):
			from .Sync import SyncCls
			self._sync = SyncCls(self._core, self._cmd_group)
		return self._sync

	@property
	def pattern(self):
		"""pattern commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_pattern'):
			from .Pattern import PatternCls
			self._pattern = PatternCls(self._core, self._cmd_group)
		return self._pattern

	@property
	def pulse(self):
		"""pulse commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_pulse'):
			from .Pulse import PulseCls
			self._pulse = PulseCls(self._core, self._cmd_group)
		return self._pulse

	@property
	def time(self):
		"""time commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_time'):
			from .Time import TimeCls
			self._time = TimeCls(self._core, self._cmd_group)
		return self._time

	def clone(self) -> 'SearchCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SearchCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TracesCls:
	"""Traces commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("traces", core, parent)

	def set(self, mode: enums.SelectionScope) -> None:
		"""SCPI: FORMat:DEXPort:TRACes \n
		Snippet: driver.applications.k50Spurious.formatPy.dexport.traces.set(mode = enums.SelectionScope.ALL) \n
		This command selects the data to be included in a data export file (see method RsFswp.MassMemory.Store.Trace.set) . \n
			:param mode: SINGle | ALL SINGle Only a single trace is selected for export, namely the one specified by the method RsFswp.MassMemory.Store.Trace.set command. ALL Selects all active traces and result tables (e.g. 'Result Summary', marker peak list etc.) in the current application for export to an ASCII file. The trace parameter for the method RsFswp.MassMemory.Store.Trace.set command is ignored.
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.SelectionScope)
		self._core.io.write(f'FORMat:DEXPort:TRACes {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.SelectionScope:
		"""SCPI: FORMat:DEXPort:TRACes \n
		Snippet: value: enums.SelectionScope = driver.applications.k50Spurious.formatPy.dexport.traces.get() \n
		This command selects the data to be included in a data export file (see method RsFswp.MassMemory.Store.Trace.set) . \n
			:return: mode: No help available"""
		response = self._core.io.query_str(f'FORMat:DEXPort:TRACes?')
		return Conversions.str_to_scalar_enum(response, enums.SelectionScope)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class UnitCls:
	"""Unit commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("unit", core, parent)

	def set(self, unit: enums.PageMarginUnit) -> None:
		"""SCPI: HCOPy:PAGE:MARGin:UNIT \n
		Snippet: driver.hardCopy.page.margin.unit.set(unit = enums.PageMarginUnit.IN) \n
		This command defines the unit in which the margins for the printout page are configured. \n
			:param unit: MM | IN MM millimeters IN inches
		"""
		param = Conversions.enum_scalar_to_str(unit, enums.PageMarginUnit)
		self._core.io.write(f'HCOPy:PAGE:MARGin:UNIT {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.PageMarginUnit:
		"""SCPI: HCOPy:PAGE:MARGin:UNIT \n
		Snippet: value: enums.PageMarginUnit = driver.hardCopy.page.margin.unit.get() \n
		This command defines the unit in which the margins for the printout page are configured. \n
			:return: unit: MM | IN MM millimeters IN inches"""
		response = self._core.io.query_str(f'HCOPy:PAGE:MARGin:UNIT?')
		return Conversions.str_to_scalar_enum(response, enums.PageMarginUnit)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ModeCls:
	"""Mode commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mode", core, parent)

	def set(self, att_mode: enums.AttenuatorMode, inputIx=repcap.InputIx.Default) -> None:
		"""SCPI: INPut<ip>:ATTenuation:AUTO:MODE \n
		Snippet: driver.applications.k70Vsa.inputPy.attenuation.auto.mode.set(att_mode = enums.AttenuatorMode.LDIStortion, inputIx = repcap.InputIx.Default) \n
		Selects the priority for signal processing after the RF attenuation has been applied. \n
			:param att_mode: No help available
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
		"""
		param = Conversions.enum_scalar_to_str(att_mode, enums.AttenuatorMode)
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		self._core.io.write(f'INPut{inputIx_cmd_val}:ATTenuation:AUTO:MODE {param}')

	# noinspection PyTypeChecker
	def get(self, inputIx=repcap.InputIx.Default) -> enums.AttenuatorMode:
		"""SCPI: INPut<ip>:ATTenuation:AUTO:MODE \n
		Snippet: value: enums.AttenuatorMode = driver.applications.k70Vsa.inputPy.attenuation.auto.mode.get(inputIx = repcap.InputIx.Default) \n
		Selects the priority for signal processing after the RF attenuation has been applied. \n
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
			:return: att_mode: No help available"""
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		response = self._core.io.query_str(f'INPut{inputIx_cmd_val}:ATTenuation:AUTO:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.AttenuatorMode)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ConnectorCls:
	"""Connector commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("connector", core, parent)

	def set(self, connector: enums.InputConnectorB) -> None:
		"""SCPI: INPut:CONNector \n
		Snippet: driver.inputPy.connector.set(connector = enums.InputConnectorB.AIQI) \n
		This command selects the measurement channel for baseband noise measurements. \n
			:param connector: No help available
		"""
		param = Conversions.enum_scalar_to_str(connector, enums.InputConnectorB)
		self._core.io.write_with_opc(f'INPut:CONNector {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SinfoCls:
	"""Sinfo commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sinfo", core, parent)

	def get(self) -> str:
		"""SCPI: DIAGnostic:SERVice:SINFo \n
		Snippet: value: str = driver.diagnostic.service.sinfo.get() \n
		This command creates a *.zip file with important support information. The *.zip file contains the system configuration
		information ('device footprint') , the current eeprom data and a screenshot of the screen display (if available) . This
		data is stored to the C:/R_S/INSTR/USER directory on the instrument. As a result of this command, the created file name
		(including the drive and path) is returned. You can use the resulting file name information as a parameter for the method
		RsFswp.MassMemory.copy command to store the file on the controller PC. (See method RsFswp.MassMemory.copy) If you contact
		the Rohde & Schwarz support to get help for a certain problem, send this file to the support in order to identify and
		solve the problem faster. \n
			:return: filename: C:/R_S/INSTR/USER/R&S Device ID_CurrentDate_CurrentTime String containing the drive, path and file name of the created support file, where the file name consists of the following elements: R&S Device ID: The unique R&S device ID indicated in the 'Versions + Options' information CurrentDate: The date on which the file is created (YYYYMMDD) CurrentTime: The time at which the file is created (HHMMSS)"""
		response = self._core.io.query_str(f'DIAGnostic:SERVice:SINFo?')
		return trim_str_response(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ModeCls:
	"""Mode commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mode", core, parent)

	def set(self, mode: enums.PmRpointMode) -> None:
		"""SCPI: [SENSe]:ADEMod:PM:RPOint[:X]:MODE \n
		Snippet: driver.sense.ademod.pm.rpoint.x.mode.set(mode = enums.PmRpointMode.MANual) \n
		Defines how the reference position in time for 0 rad is determined. \n
			:param mode: MANual | RIGHt MANual The time is defined using [SENSe:]ADEMod:PM:RPOint[:X]. RIGHt The time of the last measured value is used as the reference position. The time of the last measured value corresponds to the acquisition time, regarding the trigger event and trigger offset, if applicable. If the acquisition time or the trigger values are changed, the reference position is automatically adapted.
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.PmRpointMode)
		self._core.io.write(f'SENSe:ADEMod:PM:RPOint:X:MODE {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.PmRpointMode:
		"""SCPI: [SENSe]:ADEMod:PM:RPOint[:X]:MODE \n
		Snippet: value: enums.PmRpointMode = driver.sense.ademod.pm.rpoint.x.mode.get() \n
		Defines how the reference position in time for 0 rad is determined. \n
			:return: mode: MANual | RIGHt MANual The time is defined using [SENSe:]ADEMod:PM:RPOint[:X]. RIGHt The time of the last measured value is used as the reference position. The time of the last measured value corresponds to the acquisition time, regarding the trigger event and trigger offset, if applicable. If the acquisition time or the trigger values are changed, the reference position is automatically adapted."""
		response = self._core.io.query_str(f'SENSe:ADEMod:PM:RPOint:X:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.PmRpointMode)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ModeCls:
	"""Mode commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mode", core, parent)

	def set(self, mode: enums.SequencerMode) -> None:
		"""SCPI: INITiate:SEQuencer:MODE \n
		Snippet: driver.initiate.sequencer.mode.set(mode = enums.SequencerMode.CDEFined) \n
		Defines the capture mode for the entire measurement sequence and all measurement groups and channels it contains. Note:
		To synchronize to the end of a measurement sequence using *OPC, *OPC? or *WAI, use SINGle Sequencer mode. \n
			:param mode: SINGle Each measurement group is started one after the other in the order of definition. All measurement channels in a group are started simultaneously and performed once. After all measurements are completed, the next group is started. After the last group, the measurement sequence is finished. CONTinuous Each measurement group is started one after the other in the order of definition. All measurement channels in a group are started simultaneously and performed once. After all measurements are completed, the next group is started. After the last group, the measurement sequence restarts with the first one and continues until it is stopped explicitly.
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.SequencerMode)
		self._core.io.write(f'INITiate:SEQuencer:MODE {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal.Types import DataType
from ...Internal.ArgSingleList import ArgSingleList
from ...Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RenameCls:
	"""Rename commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("rename", core, parent)

	def set(self, channel_name_1: str, channel_name_2: str) -> None:
		"""SCPI: INSTrument:REName \n
		Snippet: driver.instrument.rename.set(channel_name_1 = '1', channel_name_2 = '1') \n
		This command renames a channel. \n
			:param channel_name_1: String containing the name of the channel you want to rename.
			:param channel_name_2: String containing the new channel name. Note that you cannot assign an existing channel name to a new channel. If you do, an error occurs. Channel names can have a maximum of 31 characters, and must be compatible with the Windows conventions for file names. In particular, they must not contain special characters such as ':', '*', '?'.
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('channel_name_1', channel_name_1, DataType.String), ArgSingle('channel_name_2', channel_name_2, DataType.String))
		self._core.io.write(f'INSTrument:REName {param}'.rstrip())



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.RepeatedCapability import RepeatedCapability
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FlistCls:
	"""Flist commands group definition. 8 total commands, 7 Subgroups, 1 group commands
	Repeated Capability: FileList, default value after init: FileList.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("flist", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_fileList_get', 'repcap_fileList_set', repcap.FileList.Nr1)

	def repcap_fileList_set(self, fileList: repcap.FileList) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to FileList.Default
		Default value after init: FileList.Nr1"""
		self._cmd_group.set_repcap_enum_value(fileList)

	def repcap_fileList_get(self) -> repcap.FileList:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def size(self):
		"""size commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_size'):
			from .Size import SizeCls
			self._size = SizeCls(self._core, self._cmd_group)
		return self._size

	@property
	def catalog(self):
		"""catalog commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_catalog'):
			from .Catalog import CatalogCls
			self._catalog = CatalogCls(self._core, self._cmd_group)
		return self._catalog

	@property
	def remove(self):
		"""remove commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_remove'):
			from .Remove import RemoveCls
			self._remove = RemoveCls(self._core, self._cmd_group)
		return self._remove

	@property
	def select(self):
		"""select commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_select'):
			from .Select import SelectCls
			self._select = SelectCls(self._core, self._cmd_group)
		return self._select

	@property
	def insert(self):
		"""insert commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_insert'):
			from .Insert import InsertCls
			self._insert = InsertCls(self._core, self._cmd_group)
		return self._insert

	@property
	def magnitude(self):
		"""magnitude commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_magnitude'):
			from .Magnitude import MagnitudeCls
			self._magnitude = MagnitudeCls(self._core, self._cmd_group)
		return self._magnitude

	@property
	def phase(self):
		"""phase commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_phase'):
			from .Phase import PhaseCls
			self._phase = PhaseCls(self._core, self._cmd_group)
		return self._phase

	def clear(self, inputIx=repcap.InputIx.Default, fileList=repcap.FileList.Default) -> None:
		"""SCPI: [SENSe]:CORRection:FRESponse:INPut<ip>:USER:FLISt<fli>:CLEar \n
		Snippet: driver.sense.correction.fresponse.inputPy.user.flist.clear(inputIx = repcap.InputIx.Default, fileList = repcap.FileList.Default) \n
		No command help available \n
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
			:param fileList: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Flist')
		"""
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		fileList_cmd_val = self._cmd_group.get_repcap_cmd_value(fileList, repcap.FileList)
		self._core.io.write(f'SENSe:CORRection:FRESponse:INPut{inputIx_cmd_val}:USER:FLISt{fileList_cmd_val}:CLEar')

	def clear_with_opc(self, inputIx=repcap.InputIx.Default, fileList=repcap.FileList.Default, opc_timeout_ms: int = -1) -> None:
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		fileList_cmd_val = self._cmd_group.get_repcap_cmd_value(fileList, repcap.FileList)
		"""SCPI: [SENSe]:CORRection:FRESponse:INPut<ip>:USER:FLISt<fli>:CLEar \n
		Snippet: driver.sense.correction.fresponse.inputPy.user.flist.clear_with_opc(inputIx = repcap.InputIx.Default, fileList = repcap.FileList.Default) \n
		No command help available \n
		Same as clear, but waits for the operation to complete before continuing further. Use the RsFswp.utilities.opc_timeout_set() to set the timeout value. \n
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
			:param fileList: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Flist')
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SENSe:CORRection:FRESponse:INPut{inputIx_cmd_val}:USER:FLISt{fileList_cmd_val}:CLEar', opc_timeout_ms)

	def clone(self) -> 'FlistCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = FlistCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RefLevelCls:
	"""RefLevel commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("refLevel", core, parent)

	def set(self, ref_level: int, rangePy=repcap.RangePy.Default) -> None:
		"""SCPI: [SENSe]:LIST:RANGe<ri>:RLEVel \n
		Snippet: driver.applications.k50Spurious.sense.listPy.range.refLevel.set(ref_level = 1, rangePy = repcap.RangePy.Default) \n
		No command help available \n
			:param ref_level: Range: -130 dBm to 30 dBm (–10 dBm + RF attenuation – RF preamplifier gain) , Unit: DBM
			:param rangePy: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Range')
		"""
		param = Conversions.decimal_value_to_str(ref_level)
		rangePy_cmd_val = self._cmd_group.get_repcap_cmd_value(rangePy, repcap.RangePy)
		self._core.io.write(f'SENSe:LIST:RANGe{rangePy_cmd_val}:RLEVel {param}')

	def get(self, rangePy=repcap.RangePy.Default) -> int:
		"""SCPI: [SENSe]:LIST:RANGe<ri>:RLEVel \n
		Snippet: value: int = driver.applications.k50Spurious.sense.listPy.range.refLevel.get(rangePy = repcap.RangePy.Default) \n
		No command help available \n
			:param rangePy: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Range')
			:return: ref_level: Range: -130 dBm to 30 dBm (–10 dBm + RF attenuation – RF preamplifier gain) , Unit: DBM"""
		rangePy_cmd_val = self._cmd_group.get_repcap_cmd_value(rangePy, repcap.RangePy)
		response = self._core.io.query_str(f'SENSe:LIST:RANGe{rangePy_cmd_val}:RLEVel?')
		return Conversions.str_to_int(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ListPyCls:
	"""ListPy commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("listPy", core, parent)

	@property
	def continuous(self):
		"""continuous commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_continuous'):
			from .Continuous import ContinuousCls
			self._continuous = ContinuousCls(self._core, self._cmd_group)
		return self._continuous

	@property
	def single(self):
		"""single commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_single'):
			from .Single import SingleCls
			self._single = SingleCls(self._core, self._cmd_group)
		return self._single

	def clone(self) -> 'ListPyCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ListPyCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class HumsCls:
	"""Hums commands group definition. 25 total commands, 13 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("hums", core, parent)

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	@property
	def all(self):
		"""all commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_all'):
			from .All import AllCls
			self._all = AllCls(self._core, self._cmd_group)
		return self._all

	@property
	def utilization(self):
		"""utilization commands group. 2 Sub-classes, 1 commands."""
		if not hasattr(self, '_utilization'):
			from .Utilization import UtilizationCls
			self._utilization = UtilizationCls(self._core, self._cmd_group)
		return self._utilization

	@property
	def bios(self):
		"""bios commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bios'):
			from .Bios import BiosCls
			self._bios = BiosCls(self._core, self._cmd_group)
		return self._bios

	@property
	def device(self):
		"""device commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_device'):
			from .Device import DeviceCls
			self._device = DeviceCls(self._core, self._cmd_group)
		return self._device

	@property
	def equipment(self):
		"""equipment commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_equipment'):
			from .Equipment import EquipmentCls
			self._equipment = EquipmentCls(self._core, self._cmd_group)
		return self._equipment

	@property
	def sw(self):
		"""sw commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sw'):
			from .Sw import SwCls
			self._sw = SwCls(self._core, self._cmd_group)
		return self._sw

	@property
	def storage(self):
		"""storage commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_storage'):
			from .Storage import StorageCls
			self._storage = StorageCls(self._core, self._cmd_group)
		return self._storage

	@property
	def system(self):
		"""system commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_system'):
			from .System import SystemCls
			self._system = SystemCls(self._core, self._cmd_group)
		return self._system

	@property
	def security(self):
		"""security commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_security'):
			from .Security import SecurityCls
			self._security = SecurityCls(self._core, self._cmd_group)
		return self._security

	@property
	def service(self):
		"""service commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_service'):
			from .Service import ServiceCls
			self._service = ServiceCls(self._core, self._cmd_group)
		return self._service

	@property
	def tags(self):
		"""tags commands group. 2 Sub-classes, 2 commands."""
		if not hasattr(self, '_tags'):
			from .Tags import TagsCls
			self._tags = TagsCls(self._core, self._cmd_group)
		return self._tags

	@property
	def formatPy(self):
		"""formatPy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_formatPy'):
			from .FormatPy import FormatPyCls
			self._formatPy = FormatPyCls(self._core, self._cmd_group)
		return self._formatPy

	def delete_all(self) -> None:
		"""SCPI: DIAGnostic:HUMS:DELete:ALL \n
		Snippet: driver.diagnostic.hums.delete_all() \n
		Deletes the complete HUMS data. This includes device history, device tags, SCPI connections, utilization history and
		utilizations. \n
		"""
		self._core.io.write(f'DIAGnostic:HUMS:DELete:ALL')

	def delete_all_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: DIAGnostic:HUMS:DELete:ALL \n
		Snippet: driver.diagnostic.hums.delete_all_with_opc() \n
		Deletes the complete HUMS data. This includes device history, device tags, SCPI connections, utilization history and
		utilizations. \n
		Same as delete_all, but waits for the operation to complete before continuing further. Use the RsFswp.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'DIAGnostic:HUMS:DELete:ALL', opc_timeout_ms)

	def save(self, path: str) -> None:
		"""SCPI: DIAGnostic:HUMS:SAVE \n
		Snippet: driver.diagnostic.hums.save(path = '1') \n
		No command help available \n
			:param path: No help available
		"""
		param = Conversions.value_to_quoted_str(path)
		self._core.io.write(f'DIAGnostic:HUMS:SAVE {param}')

	def clone(self) -> 'HumsCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = HumsCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ImmediateCls:
	"""Immediate commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("immediate", core, parent)

	def set(self) -> None:
		"""SCPI: INITiate[:IMMediate] \n
		Snippet: driver.applications.k70Vsa.initiate.immediate.set() \n
		This command starts a (single) new measurement. For a statistics count > 0, this means a restart of the corresponding
		number of measurements. With trace mode MAXHold, MINHold and AVERage, the previous results are reset on restarting the
		measurement. You can synchronize to the end of the measurement with *OPC, *OPC? or *WAI. For details on synchronization
		see Remote control via SCPI. \n
		"""
		self._core.io.write(f'INITiate:IMMediate')

	def set_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: INITiate[:IMMediate] \n
		Snippet: driver.applications.k70Vsa.initiate.immediate.set_with_opc() \n
		This command starts a (single) new measurement. For a statistics count > 0, this means a restart of the corresponding
		number of measurements. With trace mode MAXHold, MINHold and AVERage, the previous results are reset on restarting the
		measurement. You can synchronize to the end of the measurement with *OPC, *OPC? or *WAI. For details on synchronization
		see Remote control via SCPI. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsFswp.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'INITiate:IMMediate', opc_timeout_ms)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NstateCls:
	"""Nstate commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("nstate", core, parent)

	def set(self, apskn_state: float) -> None:
		"""SCPI: [SENSe]:DDEMod:APSK:NSTate \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.apsk.nstate.set(apskn_state = 1.0) \n
		This command defines the specific demodulation mode for APSK. \n
			:param apskn_state: 16 | 32 16 16APSK 32 32APSK
		"""
		param = Conversions.decimal_value_to_str(apskn_state)
		self._core.io.write(f'SENSe:DDEMod:APSK:NSTate {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:DDEMod:APSK:NSTate \n
		Snippet: value: float = driver.applications.k70Vsa.sense.ddemod.apsk.nstate.get() \n
		This command defines the specific demodulation mode for APSK. \n
			:return: apskn_state: 16 | 32 16 16APSK 32 32APSK"""
		response = self._core.io.query_str(f'SENSe:DDEMod:APSK:NSTate?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FormatPyCls:
	"""FormatPy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("formatPy", core, parent)

	def set(self, qam_format: enums.QamFormat) -> None:
		"""SCPI: [SENSe]:DDEMod:QAM:FORMat \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.qam.formatPy.set(qam_format = enums.QamFormat.DIFFerential) \n
		This command defines the specific demodulation order for QAM. \n
			:param qam_format: NORMal | DIFFerential | NPI4 | MNPi4 NORMal Demodulation order QAM is used. DIFFerential Demodulation order DQAM is used. NPI4 Demodulation order π/4-16QAM is used. MNPI4 Demodulation order -π/4-32QAM is used.
		"""
		param = Conversions.enum_scalar_to_str(qam_format, enums.QamFormat)
		self._core.io.write(f'SENSe:DDEMod:QAM:FORMat {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.QamFormat:
		"""SCPI: [SENSe]:DDEMod:QAM:FORMat \n
		Snippet: value: enums.QamFormat = driver.applications.k70Vsa.sense.ddemod.qam.formatPy.get() \n
		This command defines the specific demodulation order for QAM. \n
			:return: qam_format: NORMal | DIFFerential | NPI4 | MNPi4 NORMal Demodulation order QAM is used. DIFFerential Demodulation order DQAM is used. NPI4 Demodulation order π/4-16QAM is used. MNPI4 Demodulation order -π/4-32QAM is used."""
		response = self._core.io.query_str(f'SENSe:DDEMod:QAM:FORMat?')
		return Conversions.str_to_scalar_enum(response, enums.QamFormat)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CurrentCls:
	"""Current commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("current", core, parent)

	def get(self) -> float:
		"""SCPI: [SENSe]:SWEep:COUNt:CURRent \n
		Snippet: value: float = driver.sense.sweep.count.current.get() \n
		This query returns the current number of started sweeps or measurements. This command is only available if a sweep count
		value is defined and the instrument is in single sweep mode. \n
			:return: current_count: No help available"""
		response = self._core.io.query_str(f'SENSe:SWEep:COUNt:CURRent?')
		return Conversions.str_to_float(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CouplingCls:
	"""Coupling commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("coupling", core, parent)

	def set(self, coupling_type: enums.CouplingTypeB) -> None:
		"""SCPI: TRIGger[:SEQuence]:OSCilloscope:COUPling \n
		Snippet: driver.trigger.sequence.oscilloscope.coupling.set(coupling_type = enums.CouplingTypeB.AC) \n
		No command help available \n
			:param coupling_type: No help available
		"""
		param = Conversions.enum_scalar_to_str(coupling_type, enums.CouplingTypeB)
		self._core.io.write(f'TRIGger:SEQuence:OSCilloscope:COUPling {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.CouplingTypeB:
		"""SCPI: TRIGger[:SEQuence]:OSCilloscope:COUPling \n
		Snippet: value: enums.CouplingTypeB = driver.trigger.sequence.oscilloscope.coupling.get() \n
		No command help available \n
			:return: coupling_type: No help available"""
		response = self._core.io.query_str(f'TRIGger:SEQuence:OSCilloscope:COUPling?')
		return Conversions.str_to_scalar_enum(response, enums.CouplingTypeB)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ModeCls:
	"""Mode commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mode", core, parent)

	def set(self, statistic_mode: enums.StatisticMode, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:STATistics:MODE \n
		Snippet: driver.applications.k70Vsa.calculate.statistics.mode.set(statistic_mode = enums.StatisticMode.INFinite, window = repcap.Window.Default) \n
		This command defines whether only the symbol points or all points are considered for the statistical calculations. \n
			:param statistic_mode: SONLy | INFinite SONLy Symbol points only are used INFinite All points are used
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = Conversions.enum_scalar_to_str(statistic_mode, enums.StatisticMode)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:STATistics:MODE {param}')

	# noinspection PyTypeChecker
	def get(self, window=repcap.Window.Default) -> enums.StatisticMode:
		"""SCPI: CALCulate<n>:STATistics:MODE \n
		Snippet: value: enums.StatisticMode = driver.applications.k70Vsa.calculate.statistics.mode.get(window = repcap.Window.Default) \n
		This command defines whether only the symbol points or all points are considered for the statistical calculations. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: statistic_mode: SONLy | INFinite SONLy Symbol points only are used INFinite All points are used"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:STATistics:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.StatisticMode)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.Types import DataType
from .......Internal.ArgSingleList import ArgSingleList
from .......Internal.ArgSingle import ArgSingle
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class UserCls:
	"""User commands group definition. 4 total commands, 1 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("user", core, parent)

	@property
	def all(self):
		"""all commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_all'):
			from .All import AllCls
			self._all = AllCls(self._core, self._cmd_group)
		return self._all

	def set(self, name: str, access: enums.AccessType, level: enums.UserLevel, auth_pwd: str = None, priv_pwd: str = None) -> None:
		"""SCPI: SYSTem:COMMunicate:SNMP:USM:USER \n
		Snippet: driver.system.communicate.snmp.usm.user.set(name = '1', access = enums.AccessType.RO, level = enums.UserLevel.AUTH, auth_pwd = '1', priv_pwd = '1') \n
		Defines an SNMP user profile.
			INTRO_CMD_HELP: Prerequisites for this command: \n
			- Select SNMPv3 (method RsFswp.System.Communicate.Snmp.Version.set) . \n
			:param name: String containing name of the user.
			:param access: RO | RW Defines the access right a user can have.
			:param level: NOAuth | AUTH | PRIVacy Defines the security level.
			:param auth_pwd: String containing the authentication password.
			:param priv_pwd: String containing the privacy password.
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('name', name, DataType.String), ArgSingle('access', access, DataType.Enum, enums.AccessType), ArgSingle('level', level, DataType.Enum, enums.UserLevel), ArgSingle('auth_pwd', auth_pwd, DataType.String, None, is_optional=True), ArgSingle('priv_pwd', priv_pwd, DataType.String, None, is_optional=True))
		self._core.io.write(f'SYSTem:COMMunicate:SNMP:USM:USER {param}'.rstrip())

	def delete(self, name: str) -> None:
		"""SCPI: SYSTem:COMMunicate:SNMP:USM:USER:DELete \n
		Snippet: driver.system.communicate.snmp.usm.user.delete(name = '1') \n
		Deletes a specific SNMP user profile. \n
			:param name: String containing name of SNMP user profile to be deleted.
		"""
		param = Conversions.value_to_quoted_str(name)
		self._core.io.write(f'SYSTem:COMMunicate:SNMP:USM:USER:DELete {param}')

	def delete_all(self) -> None:
		"""SCPI: SYSTem:COMMunicate:SNMP:USM:USER:DELete:ALL \n
		Snippet: driver.system.communicate.snmp.usm.user.delete_all() \n
		Deletes all SNMP user profiles. \n
		"""
		self._core.io.write(f'SYSTem:COMMunicate:SNMP:USM:USER:DELete:ALL')

	def delete_all_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: SYSTem:COMMunicate:SNMP:USM:USER:DELete:ALL \n
		Snippet: driver.system.communicate.snmp.usm.user.delete_all_with_opc() \n
		Deletes all SNMP user profiles. \n
		Same as delete_all, but waits for the operation to complete before continuing further. Use the RsFswp.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SYSTem:COMMunicate:SNMP:USM:USER:DELete:ALL', opc_timeout_ms)

	def clone(self) -> 'UserCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = UserCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LengthCls:
	"""Length commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("length", core, parent)

	def set(self, length: int) -> None:
		"""SCPI: [SENSe]:IQ:FFT:LENGth \n
		Snippet: driver.applications.iqAnalyzer.sense.iq.fft.length.set(length = 1) \n
		Defines the number of frequency points determined by each FFT calculation. The more points are used, the higher the
		resolution in the spectrum becomes, but the longer the calculation takes. \n
			:param length: integer value Range: 3 to 524288
		"""
		param = Conversions.decimal_value_to_str(length)
		self._core.io.write(f'SENSe:IQ:FFT:LENGth {param}')

	def get(self) -> int:
		"""SCPI: [SENSe]:IQ:FFT:LENGth \n
		Snippet: value: int = driver.applications.iqAnalyzer.sense.iq.fft.length.get() \n
		Defines the number of frequency points determined by each FFT calculation. The more points are used, the higher the
		resolution in the spectrum becomes, but the longer the calculation takes. \n
			:return: length: No help available"""
		response = self._core.io.query_str(f'SENSe:IQ:FFT:LENGth?')
		return Conversions.str_to_int(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PdivisionCls:
	"""Pdivision commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pdivision", core, parent)

	def set(self, pdiv: float, window=repcap.Window.Default, trace=repcap.Trace.Default) -> None:
		"""SCPI: DISPlay[:WINDow<n>]:TRACe<t>:X[:SCALe]:PDIVision \n
		Snippet: driver.applications.k70Vsa.display.window.trace.x.scale.pdivision.set(pdiv = 1.0, window = repcap.Window.Default, trace = repcap.Trace.Default) \n
		This command defines the scaling of the x-axis for statistical result displays. For all other result displays, this
		command is only available as a query. \n
			:param pdiv: Defines the range per division (total range = 10*PDiv)
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Trace')
		"""
		param = Conversions.decimal_value_to_str(pdiv)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		self._core.io.write(f'DISPlay:WINDow{window_cmd_val}:TRACe{trace_cmd_val}:X:SCALe:PDIVision {param}')

	def get(self, window=repcap.Window.Default, trace=repcap.Trace.Default) -> float:
		"""SCPI: DISPlay[:WINDow<n>]:TRACe<t>:X[:SCALe]:PDIVision \n
		Snippet: value: float = driver.applications.k70Vsa.display.window.trace.x.scale.pdivision.get(window = repcap.Window.Default, trace = repcap.Trace.Default) \n
		This command defines the scaling of the x-axis for statistical result displays. For all other result displays, this
		command is only available as a query. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Trace')
			:return: pdiv: Defines the range per division (total range = 10*PDiv)"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		response = self._core.io.query_str(f'DISPlay:WINDow{window_cmd_val}:TRACe{trace_cmd_val}:X:SCALe:PDIVision?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ShowCls:
	"""Show commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("show", core, parent)

	def set(self, state: bool, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:MSRA:ALINe:SHOW \n
		Snippet: driver.applications.k70Vsa.calculate.msra.aline.show.set(state = False, window = repcap.Window.Default) \n
		This command defines whether or not the analysis line is displayed in all time-based windows in all MSRA secondary
		applications and the MSRA primary application. Note: even if the analysis line display is off, the indication whether or
		not the currently defined line position lies within the analysis interval of the active secondary application remains in
		the window title bars. \n
			:param state: ON | OFF | 0 | 1 OFF | 0 Switches the function off ON | 1 Switches the function on
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = Conversions.bool_to_str(state)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:MSRA:ALINe:SHOW {param}')

	def get(self, window=repcap.Window.Default) -> bool:
		"""SCPI: CALCulate<n>:MSRA:ALINe:SHOW \n
		Snippet: value: bool = driver.applications.k70Vsa.calculate.msra.aline.show.get(window = repcap.Window.Default) \n
		This command defines whether or not the analysis line is displayed in all time-based windows in all MSRA secondary
		applications and the MSRA primary application. Note: even if the analysis line display is off, the indication whether or
		not the currently defined line position lies within the analysis interval of the active secondary application remains in
		the window title bars. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: state: ON | OFF | 0 | 1 OFF | 0 Switches the function off ON | 1 Switches the function on"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:MSRA:ALINe:SHOW?')
		return Conversions.str_to_bool(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StypeCls:
	"""Stype commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("stype", core, parent)

	def set(self, type_py: enums.MeasurementType) -> None:
		"""SCPI: [SENSe]:SSEarch:STYPe \n
		Snippet: driver.applications.k50Spurious.sense.ssearch.stype.set(type_py = enums.MeasurementType.DIRected) \n
		Defines the type of measurement to be configured and performed. \n
			:param type_py: WIDE | DIRected WIDE A measurement with a large span to detect any possible spurs in the entire frequency span of an input signal. This measurement is useful if you have little or no knowledge of the current input signal or where to expect spurs, and require an overview. DIRected A measurement performed at predefined discrete frequencies with settings optimized for the current signal and noise levels at those frequencies. This measurement is targeted at determining the precise level and exact frequency of spurs that are basically already known or expected.
		"""
		param = Conversions.enum_scalar_to_str(type_py, enums.MeasurementType)
		self._core.io.write(f'SENSe:SSEarch:STYPe {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.MeasurementType:
		"""SCPI: [SENSe]:SSEarch:STYPe \n
		Snippet: value: enums.MeasurementType = driver.applications.k50Spurious.sense.ssearch.stype.get() \n
		Defines the type of measurement to be configured and performed. \n
			:return: type_py: WIDE | DIRected WIDE A measurement with a large span to detect any possible spurs in the entire frequency span of an input signal. This measurement is useful if you have little or no knowledge of the current input signal or where to expect spurs, and require an overview. DIRected A measurement performed at predefined discrete frequencies with settings optimized for the current signal and noise levels at those frequencies. This measurement is targeted at determining the precise level and exact frequency of spurs that are basically already known or expected."""
		response = self._core.io.query_str(f'SENSe:SSEarch:STYPe?')
		return Conversions.str_to_scalar_enum(response, enums.MeasurementType)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class OutputCls:
	"""Output commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("output", core, parent)

	def set(self, signal_level: enums.SignalLevel) -> None:
		"""SCPI: SOURce:GENerator:PULSe:TRIGger:OUTPut \n
		Snippet: driver.applications.k30NoiseFigure.source.generator.pulse.trigger.output.set(signal_level = enums.SignalLevel.HIGH) \n
		No command help available \n
			:param signal_level: No help available
		"""
		param = Conversions.enum_scalar_to_str(signal_level, enums.SignalLevel)
		self._core.io.write(f'SOURce:GENerator:PULSe:TRIGger:OUTPut {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.SignalLevel:
		"""SCPI: SOURce:GENerator:PULSe:TRIGger:OUTPut \n
		Snippet: value: enums.SignalLevel = driver.applications.k30NoiseFigure.source.generator.pulse.trigger.output.get() \n
		No command help available \n
			:return: signal_level: No help available"""
		response = self._core.io.query_str(f'SOURce:GENerator:PULSe:TRIGger:OUTPut?')
		return Conversions.str_to_scalar_enum(response, enums.SignalLevel)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FrequencyCls:
	"""Frequency commands group definition. 6 total commands, 4 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("frequency", core, parent)

	@property
	def offset(self):
		"""offset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_offset'):
			from .Offset import OffsetCls
			self._offset = OffsetCls(self._core, self._cmd_group)
		return self._offset

	@property
	def factor(self):
		"""factor commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_factor'):
			from .Factor import FactorCls
			self._factor = FactorCls(self._core, self._cmd_group)
		return self._factor

	@property
	def sweep(self):
		"""sweep commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_sweep'):
			from .Sweep import SweepCls
			self._sweep = SweepCls(self._core, self._cmd_group)
		return self._sweep

	@property
	def coupling(self):
		"""coupling commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_coupling'):
			from .Coupling import CouplingCls
			self._coupling = CouplingCls(self._core, self._cmd_group)
		return self._coupling

	def set(self, frequency: float, externalGen=repcap.ExternalGen.Nr1) -> None:
		"""SCPI: SOURce:EXTernal<gen>:FREQuency \n
		Snippet: driver.source.external.frequency.set(frequency = 1.0, externalGen = repcap.ExternalGen.Nr1) \n
		No command help available \n
			:param frequency: No help available
			:param externalGen: optional repeated capability selector. Default value: Nr1
		"""
		param = Conversions.decimal_value_to_str(frequency)
		externalGen_cmd_val = self._cmd_group.get_repcap_cmd_value(externalGen, repcap.ExternalGen)
		self._core.io.write(f'SOURce:EXTernal{externalGen_cmd_val}:FREQuency {param}')

	def get(self, externalGen=repcap.ExternalGen.Nr1) -> float:
		"""SCPI: SOURce:EXTernal<gen>:FREQuency \n
		Snippet: value: float = driver.source.external.frequency.get(externalGen = repcap.ExternalGen.Nr1) \n
		No command help available \n
			:param externalGen: optional repeated capability selector. Default value: Nr1
			:return: frequency: No help available"""
		externalGen_cmd_val = self._cmd_group.get_repcap_cmd_value(externalGen, repcap.ExternalGen)
		response = self._core.io.query_str(f'SOURce:EXTernal{externalGen_cmd_val}:FREQuency?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'FrequencyCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = FrequencyCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SourceCls:
	"""Source commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("source", core, parent)

	def set(self, source: enums.Source, outputConnector=repcap.OutputConnector.Default) -> None:
		"""SCPI: OUTPut<up>:IF[:SOURce] \n
		Snippet: driver.applications.k70Vsa.output.ifreq.source.set(source = enums.Source.AM, outputConnector = repcap.OutputConnector.Default) \n
		Defines the type of signal available at one of the output connectors of the R&S FSWP. \n
			:param source: IF The measured IF value is available at the IF/VIDEO/DEMOD output connector. VIDeo The displayed video signal (i.e. the filtered and detected IF signal, 200mV) is available at the IF/VIDEO/DEMOD output connector. This setting is required to provide demodulated audio frequencies at the output.
			:param outputConnector: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Output')
		"""
		param = Conversions.enum_scalar_to_str(source, enums.Source)
		outputConnector_cmd_val = self._cmd_group.get_repcap_cmd_value(outputConnector, repcap.OutputConnector)
		self._core.io.write(f'OUTPut{outputConnector_cmd_val}:IF:SOURce {param}')

	# noinspection PyTypeChecker
	def get(self, outputConnector=repcap.OutputConnector.Default) -> enums.Source:
		"""SCPI: OUTPut<up>:IF[:SOURce] \n
		Snippet: value: enums.Source = driver.applications.k70Vsa.output.ifreq.source.get(outputConnector = repcap.OutputConnector.Default) \n
		Defines the type of signal available at one of the output connectors of the R&S FSWP. \n
			:param outputConnector: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Output')
			:return: source: IF The measured IF value is available at the IF/VIDEO/DEMOD output connector. VIDeo The displayed video signal (i.e. the filtered and detected IF signal, 200mV) is available at the IF/VIDEO/DEMOD output connector. This setting is required to provide demodulated audio frequencies at the output."""
		outputConnector_cmd_val = self._cmd_group.get_repcap_cmd_value(outputConnector, repcap.OutputConnector)
		response = self._core.io.query_str(f'OUTPut{outputConnector_cmd_val}:IF:SOURce?')
		return Conversions.str_to_scalar_enum(response, enums.Source)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class EvmCls:
	"""Evm commands group definition. 18 total commands, 6 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("evm", core, parent)

	@property
	def rcurrent(self):
		"""rcurrent commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_rcurrent'):
			from .Rcurrent import RcurrentCls
			self._rcurrent = RcurrentCls(self._core, self._cmd_group)
		return self._rcurrent

	@property
	def rmean(self):
		"""rmean commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_rmean'):
			from .Rmean import RmeanCls
			self._rmean = RmeanCls(self._core, self._cmd_group)
		return self._rmean

	@property
	def rpeak(self):
		"""rpeak commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_rpeak'):
			from .Rpeak import RpeakCls
			self._rpeak = RpeakCls(self._core, self._cmd_group)
		return self._rpeak

	@property
	def pcurrent(self):
		"""pcurrent commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_pcurrent'):
			from .Pcurrent import PcurrentCls
			self._pcurrent = PcurrentCls(self._core, self._cmd_group)
		return self._pcurrent

	@property
	def pmean(self):
		"""pmean commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_pmean'):
			from .Pmean import PmeanCls
			self._pmean = PmeanCls(self._core, self._cmd_group)
		return self._pmean

	@property
	def ppeak(self):
		"""ppeak commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_ppeak'):
			from .Ppeak import PpeakCls
			self._ppeak = PpeakCls(self._core, self._cmd_group)
		return self._ppeak

	def clone(self) -> 'EvmCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = EvmCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group
